#!/usr/bin/python

from argparse import ArgumentParser
from os import remove
from pathlib import Path
from subprocess import run

parser = ArgumentParser(description='Clean public pacman repositories')
parser.add_argument('pkgs', metavar='P', type=str, nargs='*', help='packages to clean')
parser.add_argument('--old', action='store_true', help='delete old packages')
parser.add_argument('--all', action='store_true', help='delete all packages')

args = parser.parse_args()

p = Path('.')

if not args.pkgs and not args.old and not args.all:
    print('Please specify at least one package to clean.')
    exit(1)

try:
    db = list(p.glob('*.db.tar.gz'))[0]
except IndexError:
    print('There is no pacman database in the current directory.')
    exit(1)

if args.pkgs:
    for pkg in args.pkgs:
        print(f'Removing {pkg} from {db.name}')
        for f in list(p.glob(f'{pkg}-*.pkg.tar.xz')) + list(p.glob(f'{pkg}-*.pkg.tar.zst')):
            if '*' in pkg or f.name.count('-') == pkg.count('-') + 3:
                pkgname = '-'.join(f.name.split('-')[:-3])
                run(['repo-remove', db.name, pkgname])
                print(f'Deleting {f.name}')
                remove(f)
                print(f'Deleting {f.name}.sig')
                remove(f.with_suffix(f'{f.suffixes[-1]}.sig'))

if args.old:
    pkgs = [pkg for pkg in p.iterdir() if pkg.name.endswith('.pkg.tar.xz') or pkg.name.endswith('.pkg.tar.zst')]

    pkg_vers = {}

    for pkg in pkgs:
        pkg = pkg.name.split('-')
        pkgname = '-'.join(pkg[:-3])
        pkgver = pkg[-3:-2][0]
        if pkgname not in pkg_vers:
            pkg_vers[pkgname] = []
        if pkgver not in pkg_vers[pkgname]:
            pkg_vers[pkgname].append(pkgver)

    for pkg in pkg_vers:
        vers = sorted(pkg_vers[pkg])[:-1]
        for ver in vers:
            for f in list(p.glob(f'{pkg}-{ver}*')):
                print(f'Deleting {f.name}')
                remove(f)

if args.all:
    pkgs = ['-'.join(pkg.name.split('-')[:-3]) for pkg in p.iterdir() if pkg.name.endswith('.pkg.tar.xz') or pkg.name.endswith('.pkg.tar.zst')]

    for pkg in pkgs:
        print(f'Removing {pkg} from {db.name}')
        for f in list(p.glob(f'{pkg}-*.pkg.tar.xz')) + list(p.glob(f'{pkg}-*.pkg.tar.zst')):
            if '*' in pkg or f.name.count('-') == pkg.count('-') + 3:
                pkgname = '-'.join(f.name.split('-')[:-3])
                run(['repo-remove', db.name, pkgname])
                print(f'Deleting {f.name}')
                remove(f)
                print(f'Deleting {f.name}.sig')
                remove(f.with_suffix(f'{f.suffixes[-1]}.sig'))

# vim: ts=4 sw=4 et:
